@@ -14,7 +14,8 @@ import requests
 from mutagen import File
 from mutagen import flac
 from mutagen import mp4
-from mutagen.id3 import TALB, TCOP, TDRC, TIT2, TPE1, TRCK, APIC, TCON, TCOM, TSRC
+from mutagen.id3 import TALB, TCOP, TDRC, TIT2, TPE1, TRCK, APIC, TCON, TCOM, TSRC, SLT, USLT
+from mutagen.easyid3 import EasyID3, ID3
 
 
 def __extension__(filepath: str):
@@ -79,6 +80,9 @@ class TagTool(object):
         self.date = ''
         self.composer = ''
         self.isrc = ''
+        self.lyrics = ''
+        
+        self.__load__()
 
 
     def save(self, coverPath: str = None):
@@ -91,7 +95,39 @@ class TagTool(object):
                 return self.__saveMp4__(coverPath)
             return False
         except Exception as e:
-            return False
+            return False, str(e)
+        
+    def addPic(self, converPath:str = None):
+        try:
+            self.__savePic__(converPath)
+            self._handle.save()
+            return True
+        except Exception as e:
+            return False, str(e)
+        
+    def addLyrics(self, lyrics: str = None):
+        try:
+            if 'mp3' in self._ext:
+                self._handle.tags.add(USLT(encoding=3, lang=u'eng', desc=u'desc', text=__tryStr__(self.lyrics)))
+            if 'flac' in self._ext:
+                self._handle.tags['lyrics'] = __tryStr__(self.lyrics)
+            if 'mp4' in self._ext or 'm4a' in self._ext:
+                self._handle.tags['\xa9lyr'] = __tryStr__(self.lyrics)
+            self._handle.save()
+            return True
+        except Exception as e:
+            return False, str(e)
+        
+    def __load__(self):
+        try:
+            if 'mp3' in self._ext:
+                return self.__getMp3__()
+            if 'flac' in self._ext:
+                return self.__getFlac__()
+            if 'mp4' in self._ext or 'm4a' in self._ext:
+                return self.__getMp4__()
+        except:
+            return
 
 
     def __saveMp3__(self, coverPath):
@@ -108,9 +144,14 @@ class TagTool(object):
         self._handle.tags.add(TDRC(encoding=3, text=self.date))
         self._handle.tags.add(TCOM(encoding=3, text=self.composer))
         self._handle.tags.add(TSRC(encoding=3, text=self.isrc))
+        self._handle.tags.add(USLT(encoding=3, lang=u'eng', desc=u'desc', text=self.lyrics))
         self.__savePic__(coverPath)
         self._handle.save()
         return True
+    
+    def __getMp3__(self):
+        if self._handle.tags is None:
+            self._handle.add_tags()
 
 
     def __saveFlac__(self, coverPath):
@@ -128,10 +169,29 @@ class TagTool(object):
         self._handle.tags['genre'] = __tryStr__(self.genre)
         self._handle.tags['date'] = __tryStr__(self.date)
         self._handle.tags['composer'] = __tryStr__(self.composer)
-        self._handle.tags['isrc'] = str(self.isrc)
+        self._handle.tags['isrc'] = __tryStr__(self.isrc)
+        self._handle.tags['lyrics'] = __tryStr__(self.lyrics)
         self.__savePic__(coverPath)
         self._handle.save()
         return True
+    
+    def __getFlac__(self):
+        if self._handle.tags is None:
+            return
+        self.title = self.__getTagItem__('title')
+        self.album = self.__getTagItem__('album')
+        self.albumartist = self.__getTagItem__('albumartist')
+        self.artist = self.__getTagItem__('artist')
+        self.copyright = self.__getTagItem__('copyright')
+        self.tracknumber = self.__getTagItem__('tracknumber')
+        self.totaltrack = self.__getTagItem__('tracktotal')
+        self.discnumber = self.__getTagItem__('discnumber')
+        self.totaldisc = self.__getTagItem__('disctotal')
+        self.genre = self.__getTagItem__('genre')
+        self.date = self.__getTagItem__('date')
+        self.composer = self.__getTagItem__('composer')
+        self.isrc = self.__getTagItem__('isrc')
+        self.lyrics = self.__getTagItem__('lyrics')
 
     def __saveMp4__(self, coverPath):
         self._handle.tags['\xa9nam'] = self.title
@@ -144,11 +204,31 @@ class TagTool(object):
         self._handle.tags['\xa9gen'] = __tryStr__(self.genre)
         self._handle.tags['\xa9day'] = __tryStr__(self.date)
         self._handle.tags['\xa9wrt'] = __tryList__(self.composer)
+        self._handle.tags['\xa9lyr'] = __tryStr__(self.lyrics)
         self.__savePic__(coverPath)
         self._handle.save()
         return True
+    
+    def __getMp4__(self):
+        self.title = self.__getTagItem__('\xa9nam')
+        self.album = self.__getTagItem__('\xa9alb')
+        self.albumartist = self.__getTagItem__('aART')
+        self.artist = self.__getTagItem__('\xa9ART')
+        self.copyright = self.__getTagItem__('\cprt')
+        self.tracknumber = self.__getTagItem__('trkn')
+        self.totaltrack = self.__getTagItem__('trkn')
+        self.discnumber = self.__getTagItem__('disk')
+        self.totaldisc = self.__getTagItem__('disk')
+        self.genre = self.__getTagItem__('\xa9gen')
+        self.date = self.__getTagItem__('\xa9day')
+        self.composer = self.__getTagItem__('\xa9wrt')
+        self.lyrics = self.__getTagItem__('\xa9lyr')
 
-
+    def __getTagItem__(self, name):
+        if name in self._handle.tags:
+            return self._handle.tags[name]
+        return ''
+    
     def __savePic__(self, coverPath):
         data = __content__(coverPath)
         if data is None:
@@ -169,3 +249,5 @@ class TagTool(object):
             pic = mp4.MP4Cover(data)
             self._handle.tags['covr'] = [pic]
 
+
+
